==> huaweicloudsdkddm-3.0.61-py2.py3-none-any.whl: huaweicloudsdkddm/v1/model/reset_user_password_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ResetUserPasswordRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'instance_id': 'str',
        'username': 'str',
        'body': 'ResetUserPasswordReq'
    }

    attribute_map = {
        'instance_id': 'instance_id',
        'username': 'username',
        'body': 'body'
    }

    def __init__(self, instance_id=None, username=None, body=None):
        """ResetUserPasswordRequest - a model defined in huaweicloud sdk"""
        
        

        self._instance_id = None
        self._username = None
        self._body = None
        self.discriminator = None

        self.instance_id = instance_id
        self.username = username
        if body is not None:
            self.body = body

    @property
    def instance_id(self):
        """Gets the instance_id of this ResetUserPasswordRequest.

        DDM实例ID。

        :return: The instance_id of this ResetUserPasswordRequest.
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this ResetUserPasswordRequest.

        DDM实例ID。

        :param instance_id: The instance_id of this ResetUserPasswordRequest.
        :type: str
        """
        self._instance_id = instance_id

    @property
    def username(self):
        """Gets the username of this ResetUserPasswordRequest.

        需要修改的DDM帐号名称。

        :return: The username of this ResetUserPasswordRequest.
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this ResetUserPasswordRequest.

        需要修改的DDM帐号名称。

        :param username: The username of this ResetUserPasswordRequest.
        :type: str
        """
        self._username = username

    @property
    def body(self):
        """Gets the body of this ResetUserPasswordRequest.


        :return: The body of this ResetUserPasswordRequest.
        :rtype: ResetUserPasswordReq
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this ResetUserPasswordRequest.


        :param body: The body of this ResetUserPasswordRequest.
        :type: ResetUserPasswordReq
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResetUserPasswordRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkddm-3.0.97-py2.py3-none-any.whl: huaweicloudsdkddm/v1/model/reset_user_password_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ResetUserPasswordRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'instance_id': 'str',
        'username': 'str',
        'body': 'ResetUserPasswordReq'
    }

    attribute_map = {
        'instance_id': 'instance_id',
        'username': 'username',
        'body': 'body'
    }

    def __init__(self, instance_id=None, username=None, body=None):
        """ResetUserPasswordRequest

        The model defined in huaweicloud sdk

        :param instance_id: DDM实例ID。
        :type instance_id: str
        :param username: 需要修改的DDM帐号名称。
        :type username: str
        :param body: Body of the ResetUserPasswordRequest
        :type body: :class:`huaweicloudsdkddm.v1.ResetUserPasswordReq`
        """
        
        

        self._instance_id = None
        self._username = None
        self._body = None
        self.discriminator = None

        self.instance_id = instance_id
        self.username = username
        if body is not None:
            self.body = body

    @property
    def instance_id(self):
        """Gets the instance_id of this ResetUserPasswordRequest.

        DDM实例ID。

        :return: The instance_id of this ResetUserPasswordRequest.
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this ResetUserPasswordRequest.

        DDM实例ID。

        :param instance_id: The instance_id of this ResetUserPasswordRequest.
        :type instance_id: str
        """
        self._instance_id = instance_id

    @property
    def username(self):
        """Gets the username of this ResetUserPasswordRequest.

        需要修改的DDM帐号名称。

        :return: The username of this ResetUserPasswordRequest.
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this ResetUserPasswordRequest.

        需要修改的DDM帐号名称。

        :param username: The username of this ResetUserPasswordRequest.
        :type username: str
        """
        self._username = username

    @property
    def body(self):
        """Gets the body of this ResetUserPasswordRequest.


        :return: The body of this ResetUserPasswordRequest.
        :rtype: :class:`huaweicloudsdkddm.v1.ResetUserPasswordReq`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this ResetUserPasswordRequest.


        :param body: The body of this ResetUserPasswordRequest.
        :type body: :class:`huaweicloudsdkddm.v1.ResetUserPasswordReq`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResetUserPasswordRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
